**Example 1: 修改实例名称**

修改两个实例的名称

Input: 

```
tccli lighthouse ModifyInstancesAttribute --cli-unfold-argument  \
    --InstanceIds lhins-ruy9d2tw lhins-rusdke45 \
    --InstanceName test
```

Output: 
```
{
    "Response": {
        "RequestId": "47421b28-de2c-486e-b244-e47e64bf7357"
    }
}
```

